using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.IO;
using Microsoft.ApplicationBlocks.ExceptionManagement;

namespace ExceptionManagementQuickStartSamples
{
	/// <summary>
	/// Exception Management Quick Start Samples.
	/// Demonstrates how application exceptions, such as 
	/// file not found can be handled by ExceptionManager.
	/// Please see app.config for ExceptionManager configuration settings.
	/// </summary>
	public class Form1 : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button btnLogon;
		private System.Windows.Forms.TextBox txtUserName;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.TextBox txtPassword;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public Form1()
		{
			InitializeComponent();		
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.btnLogon = new System.Windows.Forms.Button();
			this.txtUserName = new System.Windows.Forms.TextBox();
			this.txtPassword = new System.Windows.Forms.TextBox();
			this.label1 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.SuspendLayout();
			// 
			// btnLogon
			// 
			this.btnLogon.Location = new System.Drawing.Point(120, 112);
			this.btnLogon.Name = "btnLogon";
			this.btnLogon.TabIndex = 0;
			this.btnLogon.Text = "Logon";
			this.btnLogon.Click += new System.EventHandler(this.btnLogon_Click);
			// 
			// txtUserName
			// 
			this.txtUserName.Location = new System.Drawing.Point(120, 48);
			this.txtUserName.Name = "txtUserName";
			this.txtUserName.Size = new System.Drawing.Size(144, 20);
			this.txtUserName.TabIndex = 1;
			this.txtUserName.Text = "Fred";
			// 
			// txtPassword
			// 
			this.txtPassword.Location = new System.Drawing.Point(120, 80);
			this.txtPassword.Name = "txtPassword";
			this.txtPassword.PasswordChar = '*';
			this.txtPassword.Size = new System.Drawing.Size(144, 20);
			this.txtPassword.TabIndex = 2;
			this.txtPassword.Text = "password";
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 48);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(104, 16);
			this.label1.TabIndex = 3;
			this.label1.Text = "User Name: ";
			this.label1.TextAlign = System.Drawing.ContentAlignment.TopRight;
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(8, 80);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(104, 16);
			this.label2.TabIndex = 4;
			this.label2.Text = "Password: ";
			this.label2.TextAlign = System.Drawing.ContentAlignment.TopRight;
			// 
			// Form1
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(432, 221);
			this.Controls.AddRange(new System.Windows.Forms.Control[] {
																		  this.label2,
																		  this.label1,
																		  this.txtPassword,
																		  this.txtUserName,
																		  this.btnLogon});
			this.Name = "Form1";
			this.Text = "Exception Management Quick Start Samples";
			this.Load += new System.EventHandler(this.Form1_Load);
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Form1());
		}
		
		/// <summary>
		// Performs logon with information provided
		/// </summary>
		private bool DoLogon(string userName, string password)
		{
			try
			{	// attempt to open a text file to vefity user logon and password				
				using (FileStream fs = new FileStream( "Accounts.dat", 
						   FileMode.Open, FileAccess.Read ))
				{
					return CheckUserDetails(fs, userName, password);
				}
			}
			catch (FileNotFoundException ex )
			{	// file not found, throw a custom LogonException
				throw new LogonException( "Internal Logon Failure. User file not found", ex );
			}
		}
		
		/// <summary>
		// Simulation that will "read" user information from file
		/// </summary>
		private bool CheckUserDetails( FileStream fs, string username, string password)
		{
			// access user file and check username and password
			return true;  
		}

		private void btnLogon_Click(object sender, System.EventArgs e)
		{	
			// attempt to log in with information provided by the user
			try
			{
				if ( DoLogon(txtUserName.Text, txtPassword.Text) == true )
				{
					MessageBox.Show("Your Logon Was Successful");
				}
				else
				{
					MessageBox.Show("Logon failed. Invalid user name or password");
				}
				}
			catch( LogonException lex)
			{	// publish Exception using ExceptionManager
				ExceptionManager.Publish( lex );
				MessageBox.Show(lex.Message);
			}			
		}

		private void Form1_Load(object sender, System.EventArgs e)
		{
	
		}			
	}
}
